/// <reference types="node" />
import { Promisy, PromisyClass } from './Task';
export declare class TaskQueue<PromiseType extends Promisy<PromiseType>> {
    constructor(Promise: PromisyClass<PromiseType>, concurrency: number);
    /** Add a new task to the queue.
      * It will start when the number of other concurrent tasks is low enough.
      * @param func Function to call.
      * @param delay Initial delay in milliseconds before making the call. */
    add(func: () => any, delay?: number): any;
    /** Consider current function idle until promise resolves.
      * Useful for making recursive calls. */
    unblock(promise: PromiseType): PromiseType;
    /** Wrap a function returning a promise, so that before running
      * it waits until concurrent invocations are below this queue's limit. */
    wrap(func: (...args: any[]) => any, thisObject?: any): (...args: any[]) => any;
    /** Start the next task from the backlog. */
    private next();
    private nextBound;
    private nextTickBound;
    private Promise;
    private busyCount;
    private backlog;
    /** Number of promises allowed to resolve concurrently. */
    concurrency: number;
    timer: number | NodeJS.Timer;
    timerStamp: number;
}
